SnapPy
======

SnapPy is a package for studying the topology and geometry of
3-manifolds, with a focus on hyperbolic structures.  It is based on
the SnapPea kernel written by `Jeff Weeks
<http://www.geometrygames.org>`_.  

Complete documentation is available on the web including the `main
page <http://snappy.computop.org>`_ and an `installation guide
<http://snappy.computop.org/installing.html>`_.  You can also browse
the `source code <https://github.com/3-manifolds/SnapPy>`_.

Downloads
=========

We also provide self-contained applications for:

* `macOS <https://github.com/3-manifolds/SnapPy/releases/latest/download/SnapPy.dmg>`_
* `Windows <https://github.com/3-manifolds/SnapPy/releases/latest/download/InstallSnapPy.exe>`_

Credits
=======

Primarily developed by `Marc Culler <http://math.uic.edu/~culler>`_,
`Nathan Dunfield <http://dunfield.info>`_, and `Matthias Goerner
<http://www.unhyperbolic.org/>`_ based on SnapPea by Jeff Weeks.
With contributions from `many people
<http://snappy.computop.org/credits.html>`_.

License
=======

Copyright 2007-present by Marc Culler, Nathan Dunfield, Matthias
Goerner, Jeff Weeks and others.

This code is released under the `GNU General Public License, version 2
<http://www.gnu.org/licenses/gpl-2.0.txt>`_ or (at your option) any
later version as published by the Free Software Foundation.
